import { DateAndPlaceOfBirth, NationalIdentification } from 'ivms/types';

export type Theme = {
  primaryColor: string;
  secondaryColor: string;
  fontFamily: string;
  logo: string;
};

export type TransactionTypeAllowed =
  | 'ALL'
  | 'VASP_2_VASP_ONLY'
  | 'SELF_TRANSACTION_ONLY';

export type NonCustodialDeclarationType =
  | 'SIGNATURE'
  | 'DECLARATION'
  | 'SIGNATURE_AND_DECLARATION';

export type OwnershipProofInput = {
  type?: string | null;
  proof?: string | null;
};

export type TransactionBlockchainInfo = {
  destination?: string | null;
  origin?: string | null;
};

export type CountryType = {
  id: string;
  name: string;
};

export type PersonType = 'natural' | 'legal';

export type OriginatorFields = {
  originatorAccountNumber?: string;
  originatorDid?: string;
  originatorVASPname?: string;
  originatorVASPdid?: string;
  originatorName?: string;
  originatorGeographicAddress?: string;
  originatorNationalIdentification?: NationalIdentification;
  originatorDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  originatorPersonType?: PersonType;
};

export type BeneficiaryFields = {
  beneficiaryAccountNumber?: string;
  beneficiaryDid?: string;
  beneficiaryVASPname?: string;
  beneficiaryVASPdid?: string;
  beneficiaryName?: string;
  beneficiaryGeographicAddress?: string;
  beneficiaryNationalIdentification?: NationalIdentification;
  beneficiaryDateAndPlaceOfBirth?: DateAndPlaceOfBirth;
  beneficiaryPersonType?: PersonType;
};

export type Transaction = OriginatorFields &
  BeneficiaryFields & {
    transactionAsset: string;
    transactionAmount: string;
    transactionBlockchainInfo?: TransactionBlockchainInfo;
    isNonCustodial?: boolean;
    originatorEqualsBeneficiary?: boolean;
    beneficiaryProof?: OwnershipProofInput;
    originatorProof?: OwnershipProofInput;
    isValid?: boolean;
    errors?: string[];
  };
